@@ -23,17 +23,29 @@ import wx.lib.statbmp as wx_genstatbmp
 # GNUmed specific
 if __name__ == '__main__':
 	sys.path.insert(0, '../../')
-from Gnumed.pycommon import gmDispatcher, gmI18N, gmMatchProvider, gmPG2, gmTools, gmCfg
-from Gnumed.pycommon import gmDateTime, gmShellAPI
+from Gnumed.pycommon import gmDispatcher
+from Gnumed.pycommon import gmI18N
+from Gnumed.pycommon import gmMatchProvider
+from Gnumed.pycommon import gmPG2
+from Gnumed.pycommon import gmTools
+from Gnumed.pycommon import gmCfg
+from Gnumed.pycommon import gmDateTime
+from Gnumed.pycommon import gmShellAPI
 
 from Gnumed.business import gmDemographicRecord
 from Gnumed.business import gmPersonSearch
 from Gnumed.business import gmSurgery
 from Gnumed.business import gmPerson
 
-from Gnumed.wxpython import gmPhraseWheel, gmGuiHelpers, gmDateTimeInput
-from Gnumed.wxpython import gmRegetMixin, gmDataMiningWidgets, gmListWidgets, gmEditArea
-from Gnumed.wxpython import gmAuthWidgets, gmPersonContactWidgets
+from Gnumed.wxpython import gmPhraseWheel
+from Gnumed.wxpython import gmRegetMixin
+from Gnumed.wxpython import gmAuthWidgets
+from Gnumed.wxpython import gmPersonContactWidgets
+from Gnumed.wxpython import gmEditArea
+from Gnumed.wxpython import gmListWidgets
+from Gnumed.wxpython import gmDateTimeInput
+from Gnumed.wxpython import gmDataMiningWidgets
+from Gnumed.wxpython import gmGuiHelpers
 
 
 # constant defs
@@ -184,8 +196,14 @@ class cTagImageEAPnl(wxgTagImageEAPnl.wxgTagImageEAPnl, gmEditArea.cGenericEditA
 		return (valid is True)
 	#----------------------------------------------------------------
 	def _save_as_new(self):
-		# save the data as a new instance
-		data = gmDemographicRecord.create_tag_image(description = self._TCTRL_description.GetValue().strip())
+
+		dbo_conn = gmAuthWidgets.get_dbowner_connection(procedure = _('Creating tag with image'))
+		if dbo_conn is None:
+			return False
+
+		data = gmDemographicRecord.create_tag_image(description = self._TCTRL_description.GetValue().strip(), link_obj = dbo_conn)
+		dbo_conn.close()
+
 		data['filename'] = self._TCTRL_filename.GetValue().strip()
 		data.save()
 		data.update_image_from_file(filename = self.__selected_image_file)
@@ -197,7 +215,14 @@ class cTagImageEAPnl(wxgTagImageEAPnl.wxgTagImageEAPnl, gmEditArea.cGenericEditA
 		return True
 	#----------------------------------------------------------------
 	def _save_as_update(self):
-		# update self.data and save the changes
+
+		# this is somewhat fake as it never actually uses the gm-dbo conn
+		# (although it does verify it)
+		dbo_conn = gmAuthWidgets.get_dbowner_connection(procedure = _('Updating tag with image'))
+		if dbo_conn is None:
+			return False
+		dbo_conn.close()
+
 		self.data['description'] = self._TCTRL_description.GetValue().strip()
 		self.data['filename'] = self._TCTRL_filename.GetValue().strip()
 		self.data.save()
@@ -842,7 +867,15 @@ class cIdentityEAPnl(wxgIdentityEAPnl.wxgIdentityEAPnl, gmEditArea.cGenericEditA
 			value = self.data.get_formatted_dob(format = '%Y-%m-%d %H:%M', encoding = gmI18N.get_encoding()),
 			data = self.data['dob']
 		)
-		self._PRW_dod.SetText(value = self.data['deceased'])
+		if self.data['deceased'] is None:
+			val = u''
+		else:
+			val = gmDateTime.pydt_strftime (
+				self.data['deceased'],
+				format = '%Y-%m-%d %H:%M',
+				accuracy = gmDateTime.acc_minutes
+			)
+		self._PRW_dod.SetText(value = val, data = self.data['deceased'])
 		self._PRW_gender.SetData(self.data['gender'])
 		#self._PRW_ethnicity.SetValue()
 		self._PRW_title.SetText(gmTools.coalesce(self.data['title'], u''))
@@ -885,7 +918,15 @@ class cNameGenderDOBEditAreaPnl(wxgNameGenderDOBEditAreaPnl.wxgNameGenderDOBEdit
 		)
 		self._PRW_gender.SetData(self.__name['gender'])
 		self._CHBOX_active.SetValue(self.__name['active_name'])
-		self._PRW_dod.SetText(data = self.__identity['deceased'])
+		if self.__identity['deceased'] is None:
+			val = u''
+		else:
+			val = gmDateTime.pydt_strftime (
+				self.__identity['deceased'],
+				format = '%Y-%m-%d %H:%M',
+				accuracy = gmDateTime.acc_minutes
+			)
+		self._PRW_dod.SetText(value = val, data = self.__identity['deceased'])
 		self._TCTRL_comment.SetValue(gmTools.coalesce(self.__name['comment'], u''))
 		# FIXME: clear fields
 #		else:
