@@ -6,7 +6,7 @@ __author__ = "cfmoro1976@yahoo.es, sjtan@swiftdsl.com.au, Karsten.Hilbert@gmx.ne
 __license__ = "GPL"
 
 # std lib
-import sys, types, os.path, StringIO, codecs, logging
+import sys, os.path, StringIO, codecs, logging
 
 
 # 3rd party
@@ -16,7 +16,7 @@ import wx
 # GNUmed libs
 from Gnumed.pycommon import gmI18N, gmDispatcher, gmExceptions, gmTools
 from Gnumed.exporters import gmPatientExporter
-from Gnumed.business import gmEMRStructItems, gmPerson, gmSOAPimporter
+from Gnumed.business import gmEMRStructItems, gmPerson, gmSOAPimporter, gmPersonSearch
 from Gnumed.wxpython import gmGuiHelpers, gmEMRStructWidgets, gmSOAPWidgets
 from Gnumed.wxpython import gmAllergyWidgets, gmNarrativeWidgets, gmPatSearchWidgets
 from Gnumed.wxpython import gmDemographicsWidgets, gmVaccWidgets
@@ -87,11 +87,8 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 
 		gmGuiHelpers.cTreeExpansionHistoryMixin.__init__(self)
 
-		try:
-			self.__narr_display = kwds['narr_display']
-			del kwds['narr_display']
-		except KeyError:
-			self.__narr_display = None
+		self.__details_display = None
+		self.__details_display_mode = u'details'				# "details" or "journal"
 		self.__pat = gmPerson.gmCurrentPatient()
 		self.__curr_node = None
 		self.__exporter = gmPatientExporter.cEmrExport(patient = self.__pat)
@@ -114,7 +111,10 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		return True
 	#--------------------------------------------------------
 	def set_narrative_display(self, narrative_display=None):
-		self.__narr_display = narrative_display
+		self.__details_display = narrative_display
+	#--------------------------------------------------------
+	def set_image_display(self, image_display=None):
+		self.__img_display = image_display
 	#--------------------------------------------------------
 	# internal helpers
 	#--------------------------------------------------------
@@ -138,13 +138,54 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 
 		wx.BeginBusyCursor()
 
-		self.snapshot_expansion()
+#		self.snapshot_expansion()
 
 		# init new tree
 		self.DeleteAllItems()
-		root_item = self.AddRoot(_('EMR of %s') % self.__pat['description'])
+		root_item = self.AddRoot(_('EMR of %(lastnames)s, %(firstnames)s') % self.__pat.get_active_name())
 		self.SetPyData(root_item, None)
 		self.SetItemHasChildren(root_item, True)
+		self.__root_tooltip = self.__pat['description_gender'] + u'\n'
+		if self.__pat['deceased'] is None:
+			self.__root_tooltip += u' %s  %s (%s)\n\n' % (
+				gmPerson.map_gender2symbol[self.__pat['gender']],
+				self.__pat.get_formatted_dob(format = '%d %b %Y', encoding = gmI18N.get_encoding()),
+				self.__pat['medical_age']
+			)
+		else:
+			template = u' %s  %s - %s (%s)\n\n'
+			self.__root_tooltip += template % (
+				gmPerson.map_gender2symbol[self.__pat['gender']],
+				self.__pat.get_formatted_dob(format = '%d.%b %Y', encoding = gmI18N.get_encoding()),
+				self.__pat['deceased'].strftime('%d.%b %Y').decode(gmI18N.get_encoding()),
+				self.__pat['medical_age']
+			)
+		self.__root_tooltip += gmTools.coalesce(self.__pat['comment'], u'', u'%s\n\n')
+		doc = self.__pat.primary_provider
+		if doc is not None:
+			self.__root_tooltip += u'%s:\n' % _('Primary provider in this praxis')
+			self.__root_tooltip += u' %s %s %s (%s)%s\n\n' % (
+				gmTools.coalesce(doc['title'], gmPerson.map_gender2salutation(gender = doc['gender'])),
+				doc['firstnames'],
+				doc['lastnames'],
+				doc['short_alias'],
+				gmTools.bool2subst(doc['is_active'], u'', u' [%s]' % _('inactive'))
+			)
+		if not ((self.__pat['emergency_contact'] is None) and (self.__pat['pk_emergency_contact'] is None)):
+			self.__root_tooltip += _('In case of emergency contact:') + u'\n'
+			if self.__pat['emergency_contact'] is not None:
+				self.__root_tooltip += gmTools.wrap (
+					text = u'%s\n' % self.__pat['emergency_contact'],
+					width = 60,
+					initial_indent = u' ',
+					subsequent_indent = u' '
+				)
+			if self.__pat['pk_emergency_contact'] is not None:
+				contact = self.__pat.emergency_contact_in_database
+				self.__root_tooltip += u' %s\n' % contact['description_gender']
+		self.__root_tooltip = self.__root_tooltip.strip('\n')
+		if self.__root_tooltip == u'':
+			self.__root_tooltip = u' '
 
 		# have the tree filled by the exporter
 		self.__exporter.get_historical_tree(self)
@@ -154,7 +195,7 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		self.Expand(root_item)
 		self.__update_text_for_selected_node()
 
-		self.restore_expansion()
+#		self.restore_expansion()
 
 		wx.EndBusyCursor()
 		return True
@@ -162,35 +203,66 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 	def __update_text_for_selected_node(self):
 		"""Displays information for the selected tree node."""
 
-		if self.__narr_display is None:
+		if self.__details_display is None:
+			self.__img_display.clear()
 			return
 
 		if self.__curr_node is None:
+			self.__img_display.clear()
 			return
 
 		node_data = self.GetPyData(self.__curr_node)
+		doc_folder = self.__pat.get_document_folder()
 
-		# update displayed text
-		if isinstance(node_data, (gmEMRStructItems.cHealthIssue, types.DictType)):
-			# FIXME: turn into real dummy issue
-			if node_data['pk_health_issue'] is None:
-				txt = _('Pool of unassociated episodes:\n\n  "%s"') % node_data['description']
-			else:
+		if isinstance(node_data, gmEMRStructItems.cHealthIssue):
+			if self.__details_display_mode == u'details':
 				txt = node_data.format(left_margin=1, patient = self.__pat)
+			else:
+				txt = node_data.format_as_journal(left_margin = 1)
+
+			self.__img_display.refresh (
+				document_folder = doc_folder,
+				episodes = [ epi['pk_episode'] for epi in node_data.episodes ]
+			)
+
+		elif isinstance(node_data, type({})):
+			# FIXME: turn into real dummy issue
+			txt = _('Pool of unassociated episodes:\n\n  "%s"') % node_data['description']
+			self.__img_display.clear()
 
 		elif isinstance(node_data, gmEMRStructItems.cEpisode):
-			txt = node_data.format(left_margin = 1, patient = self.__pat)
+			if self.__details_display_mode == u'details':
+				txt = node_data.format(left_margin = 1, patient = self.__pat)
+			else:
+				txt = node_data.format_as_journal(left_margin = 1)
+			self.__img_display.refresh (
+				document_folder = doc_folder,
+				episodes = [node_data['pk_episode']]
+			)
 
 		elif isinstance(node_data, gmEMRStructItems.cEncounter):
 			epi = self.GetPyData(self.GetItemParent(self.__curr_node))
-			txt = node_data.format(episodes = [epi['pk_episode']], with_soap = True, left_margin = 1, patient = self.__pat)
+			txt = node_data.format (
+				episodes = [epi['pk_episode']],
+				with_soap = True,
+				left_margin = 1,
+				patient = self.__pat,
+				with_co_encountlet_hints = True
+			)
+			self.__img_display.refresh (
+				document_folder = doc_folder,
+				episodes = [epi['pk_episode']],
+				encounter = node_data['pk_encounter']
+			)
 
 		else:
 			emr = self.__pat.get_emr()
-			txt = emr.format_summary()
+			txt = emr.format_summary(dob = self.__pat['dob'])
+			self.__img_display.clear()
 
-		self.__narr_display.Clear()
-		self.__narr_display.WriteText(txt)
+		self.__details_display.Clear()
+		self.__details_display.WriteText(txt)
+		self.__details_display.ShowPosition(0)
 	#--------------------------------------------------------
 	def __make_popup_menus(self):
 
@@ -380,9 +452,7 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 	#--------------------------------------------------------
 	def __edit_encounter_details(self, event):
 		node_data = self.GetPyData(self.__curr_node)
-		dlg = gmEMRStructWidgets.cEncounterEditAreaDlg(parent=self, encounter=node_data)
-		dlg.ShowModal()
-		dlg.Destroy()
+		gmEMRStructWidgets.edit_encounter(parent = self, encounter = node_data)
 		self.__populate_tree()
 	#--------------------------------------------------------
 	def __relink_encounter_data2episode(self, event):
@@ -610,7 +680,9 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 				_('ongoing episode'),
 				_('closed episode'),
 				'error: episode state is None'
-			)
+			) + u'\n'
+			tt += gmTools.coalesce(data['summary'], u'', u'\n%s')
+			tt = tt.strip(u'\n')
 			if tt == u'':
 				tt = u' '
 			event.SetToolTip(tt)
@@ -632,14 +704,17 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 			tt += gmTools.bool2subst(data['is_active'], _('active') + u'\n', u'')
 			tt += gmTools.bool2subst(data['clinically_relevant'], _('clinically relevant') + u'\n', u'')
 			tt += gmTools.bool2subst(data['is_cause_of_death'], _('contributed to death') + u'\n', u'')
-			tt += gmTools.coalesce(data['grouping'], u'', _('Grouping: %s'))
+			tt += gmTools.coalesce(data['grouping'], u'\n', _('Grouping: %s') + u'\n\n')
+			tt += gmTools.coalesce(data['summary'], u'')
+			tt = tt.strip(u'\n')
 			if tt == u'':
 				tt = u' '
 			event.SetToolTip(tt)
 
 		else:
-			event.SetToolTip(u' ')
-			#self.SetToolTipString(u'')
+			event.SetToolTip(self.__root_tooltip)
+			#event.SetToolTip(u' ')
+			##self.SetToolTipString(u'')
 
 		# doing this prevents the tooltip from showing at all
 		#event.Skip()
@@ -687,7 +762,13 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		item1 = self.GetPyData(node1)
 		item2 = self.GetPyData(node2)
 
-		# encounters: reverse chron
+		# dummy health issue always on top
+		if isinstance(item1, type({})):
+			return -1
+		if isinstance(item2, type({})):
+			return 1
+
+		# encounters: reverse chronologically
 		if isinstance(item1, gmEMRStructItems.cEncounter):
 			if item1['started'] == item2['started']:
 				return 0
@@ -695,7 +776,7 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 				return -1
 			return 1
 
-		# episodes: chron
+		# episodes: chronologically
 		if isinstance(item1, gmEMRStructItems.cEpisode):
 			start1 = item1.get_access_range()[0]
 			start2 = item2.get_access_range()[0]
@@ -741,11 +822,26 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 
 			return 0
 
-		# dummy health issue always on top
-		if isinstance(item1, type({})):
-			return -1
+		_log.error('unknown item type during sorting EMR tree:')
+		_log.error('item1: %s', type(item1))
+		_log.error('item2: %s', type(item2))
 
 		return 0
+	#--------------------------------------------------------
+	# properties
+	#--------------------------------------------------------
+	def _get_details_display_mode(self):
+		return self.__details_display_mode
+
+	def _set_details_display_mode(self, mode):
+		if mode not in [u'details', u'journal']:
+			raise ValueError('details display mode must be one of "details", "journal"')
+		if self.__details_display_mode == mode:
+			return
+		self.__details_display_mode = mode
+		self.__update_text_for_selected_node()
+
+	details_display_mode = property(_get_details_display_mode, _set_details_display_mode)
 #================================================================
 from Gnumed.wxGladeWidgets import wxgScrolledEMRTreePnl
 
@@ -758,10 +854,6 @@ class cScrolledEMRTreePnl(wxgScrolledEMRTreePnl.wxgScrolledEMRTreePnl):
 	"""
 	def __init__(self, *args, **kwds):
 		wxgScrolledEMRTreePnl.wxgScrolledEMRTreePnl.__init__(self, *args, **kwds)
-#		self.__register_interests()
-	#--------------------------------------------------------
-#	def __register_interests(self):
-#		gmDispatcher.connect(signal= u'post_patient_selection', receiver=self.repopulate_ui)
 	#--------------------------------------------------------
 	def repopulate_ui(self):
 		self._emr_tree.refresh()
@@ -780,17 +872,30 @@ class cSplittedEMRTreeBrowserPnl(wxgSplittedEMRTreeBrowserPnl.wxgSplittedEMRTree
 	def __init__(self, *args, **kwds):
 		wxgSplittedEMRTreeBrowserPnl.wxgSplittedEMRTreeBrowserPnl.__init__(self, *args, **kwds)
 		self._pnl_emr_tree._emr_tree.set_narrative_display(narrative_display = self._TCTRL_item_details)
+		self._pnl_emr_tree._emr_tree.set_image_display(image_display = self._PNL_visual_soap)
 		self.__register_events()
 	#--------------------------------------------------------
 	def __register_events(self):
 		gmDispatcher.connect(signal = u'post_patient_selection', receiver = self._on_post_patient_selection)
 		return True
 	#--------------------------------------------------------
+	# event handler
+	#--------------------------------------------------------
 	def _on_post_patient_selection(self):
 		if self.GetParent().GetCurrentPage() == self:
 			self.repopulate_ui()
 		return True
 	#--------------------------------------------------------
+	def _on_show_details_selected(self, event):
+		#event.Skip()
+		self._pnl_emr_tree._emr_tree.details_display_mode = u'details'
+	#--------------------------------------------------------
+	def _on_show_journal_selected(self, event):
+		#event.Skip()
+		self._pnl_emr_tree._emr_tree.details_display_mode = u'journal'
+	#--------------------------------------------------------
+	# external API
+	#--------------------------------------------------------
 	def repopulate_ui(self):
 		"""Fills UI with data."""
 		self._pnl_emr_tree.repopulate_ui()
@@ -860,7 +965,7 @@ if __name__ == '__main__':
 
 	try:
 		# obtain patient
-		patient = gmPerson.ask_for_patient()
+		patient = gmPersonSearch.ask_for_patient()
 		if patient is None:
 			print "No patient. Exiting gracefully..."
 			sys.exit(0)
