@@ -185,8 +185,8 @@ class gmPlaceholderHandler(gmBorg.cBorg):
 			name, data, lng = parts
 			try:
 				lng = int(lng)
-			except:
-				_log.exception('placeholder length definition error: %s, discarding length', original_placeholder)
+			except (TypeError, ValueError):
+				_log.error('placeholder length definition error: %s, discarding length: >%s<', original_placeholder, lng)
 				lng = None
 		if len(parts) > 3:
 			_log.warning('invalid placeholder layout: %s', original_placeholder)
@@ -335,7 +335,7 @@ class gmPlaceholderHandler(gmBorg.cBorg):
 				cats.extend(list(data_parts[0]))
 
 			# part[1]: date format
-			if len(data_parts) > 0:
+			if len(data_parts) > 1:
 				if len(data_parts[1]) > 0:
 					date_format = data_parts[1]
 
@@ -376,25 +376,25 @@ class gmPlaceholderHandler(gmBorg.cBorg):
 				cats = list(u'soap').append(None)
 
 			# part[1]: template
-			if len(data_parts) > 0:
+			if len(data_parts) > 1:
 				template = data_parts[1]
 
 			# part[2]: line length
-			if len(data_parts) > 1:
+			if len(data_parts) > 2:
 				try:
 					line_length = int(data_parts[2])
 				except:
 					line_length = 9999
 
 			# part[3]: weeks going back in time
-			if len(data_parts) > 2:
+			if len(data_parts) > 3:
 				try:
 					time_range = 7 * int(data_parts[3])
 				except:
 					time_range = None
 
 			# part[4]: output format
-			if len(data_parts) > 3:
+			if len(data_parts) > 4:
 				target_format = data_parts[4]
 
 		# FIXME: will need to be a generator later on
@@ -451,7 +451,7 @@ class gmPlaceholderHandler(gmBorg.cBorg):
 				cats.append(None)
 
 			# part[1]: template
-			if len(data_parts) > 0:
+			if len(data_parts) > 1:
 				template = data_parts[1]
 
 		#narr = gmNarrativeWidgets.select_narrative_from_episodes_new(soap_cats = cats)
@@ -1100,7 +1100,8 @@ if __name__ == '__main__':
 
 		#ph = u'emr_journal::soap //%(date)s  %(modified_by)s  %(soap_cat)s  %(narrative)s//30::'
 		#ph = u'free_text::latex//placeholder test::9999'
-		ph = u'soap_for_encounters:://::9999'
+		#ph = u'soap_for_encounters:://::9999'
+		ph = u'soap_a'
 
 		handler = gmPlaceholderHandler()
 		handler.debug = True
